@@ -21,8 +21,6 @@ use Config::Model::Dpkg::Dependency;
 
 my $logger = get_logger("Backend::Dpkg::Control") ;
 
-sub suffix { return '' ; }
-
 sub read {
     my $self = shift ;
     my %args = @_ ;
@@ -158,7 +156,7 @@ sub store_section_element_in_tree {
     # error message
     my $found = $node->find_element( $key, case => 'any' ) || $key;
 
-    # v_ref is a list of ($value, $line_nb ,$note,@comment) = @$v_ref;
+    # v_ref is a list of (@comment , [ value, $line_nb ,$note ] )
 
     my $elt_obj = $node->fetch_element( name => $found, check => $check );
     my $type = $node->element_type($found);
@@ -167,8 +165,10 @@ sub store_section_element_in_tree {
         $self->store_section_list_element ( $logger,  $elt_obj, $check, $v_ref);
     }
     elsif ($found eq 'Description' and $elt_obj) {
-        my ($synopsis_ref, @desc_ref) = $v_ref->@*;
-        $self->store_section_leaf_element ( $logger, $node->fetch_element('Synopsis'), $check, [$synopsis_ref]);
+        my @comment = grep { not ref($_) } $v_ref->@*;
+        my ($synopsis_ref, @desc_ref) = grep { ref($_) } $v_ref->@*;
+        # comment is attached to synopsis to write it back at the same place.
+        $self->store_section_leaf_element ( $logger, $node->fetch_element('Synopsis'), $check, [@comment, $synopsis_ref]);
         $self->store_section_leaf_element ( $logger, $node->fetch_element('Description'), $check, \@desc_ref);
     }
     elsif ($elt_obj ) {
@@ -214,50 +214,30 @@ sub write {
     return 1;
 }
 
-sub package_spec {
-    my ( $self, $node ) = @_ ;
-
-    my @section ;
-    my $description_ref ;
-    foreach my $elt ($node->get_element_name ) {
-        my $type = $node->element_type($elt) ;
-        my $elt_obj = $node->fetch_element($elt) ;
-
-        my $c = $elt_obj->annotation ;
-        push @section, map {'# '.$_} split /\n/,$c if $c ;
-
-        if ($type eq 'hash') {
-            die "package_spec: unexpected hash type in ".$node->name." element $elt\n" ;
-        }
-        elsif ($type eq 'list') {
-            my @v;
-            my @indexes = $elt_obj->fetch_all_indexes;
-
-            foreach my $idx (@indexes) {
-                my $value_obj = $elt_obj->fetch_with_id($idx);
-                my $value = $value_obj->fetch;
-                next unless defined $value;
-
-                my $note = $value_obj->annotation;
-                my $comment = $note ? join ("\n",map {'# '.$_} split /\n/,$note ) : undef;
-                push @v, $comment ? [ $value, $comment ] : $value;
-            }
-            push @section, $elt , \@v if @v;
-        }
-        elsif ($elt eq 'Synopsis') {
-            my $v = $node->fetch_element_value($elt) ;
-            push @section, 'Description' , $v ; # mandatory field
-            $description_ref = \$section[$#section] ;
-        }
-        elsif ($elt eq 'Description') {
-            $$description_ref .= "\n".$node->fetch_element_value($elt) ; # mandatory field
-        }
-        else {
-            my $v = $node->fetch_element_value($elt) ;
-            push @section, $elt , $v if $v ;
-        }
+sub _re_order ($list, $move_after) {
+    my $i = 0;
+    while ( $i < $move_after->@* ) {
+        my $k = $move_after->[$i++];
+        my $v = $move_after->[$i++];
+        my ($ik, $iv);
+        my $j = 0;
+        map { $ik = $j if $_ eq $k; $iv = $j if $_ eq $v; $j++ } @$list;
+        next unless defined $ik and defined $iv;
+        splice @$list, $ik, 1; # remove $k from list
+        splice @$list, $iv, 0, $k; # add back $k after $v
     }
-    return @section ;
+}
+
+my @move_after = (
+    'Standards-Version' => 'Built-Using',
+);
+
+sub package_spec ( $self, $node ) {
+    # can't use a static list as element can be created by user (with
+    # the accept condition)
+    my @list = $node->get_element_name;
+    _re_order(\@list, \@move_after);
+    return $self->node_to_section($node, \@list)
 }
 
 
