@@ -178,9 +178,8 @@ sub write_dpkg_file {
 # TODO: also rework coyright and dpkgpatch to cope with new data structure
 
 # input is [ may_be_comment, keyword => value | value_list_ref, ... ]
-sub format_dpkg_section {
-    my ($self, $array_ref,$list_sep) = @_ ;
-
+sub format_dpkg_section ($self, $array_ref, $list_sep) {
+    $array_ref //= [] ;
     my @lines ;
 
     my $i = 0;
@@ -261,6 +260,56 @@ sub format_label_line {
     return $label_line;
 }
 
+sub node_to_section ($self, $node, $elt_list = [ $node->get_element_names ]) {
+
+    my @section ;
+    my $description_ref ;
+    foreach my $elt ( $elt_list->@* ) {
+        my $type = $node->element_type($elt) ;
+        my $elt_obj = $node->fetch_element($elt) ;
+
+        my $c = $elt_obj->annotation ;
+        push @section, map {'# '.$_} split /\n/,$c if $c ;
+
+        if ($type eq 'hash') {
+            die "package_spec: unexpected hash type in ".$node->name." element $elt\n" ;
+        }
+        elsif ($type eq 'list') {
+            my @v;
+            my @indexes = $elt_obj->fetch_all_indexes;
+
+            foreach my $idx (@indexes) {
+                my $value_obj = $elt_obj->fetch_with_id($idx);
+                my $value = $value_obj->fetch;
+                next unless defined $value;
+
+                my $note = $value_obj->annotation;
+                my $comment = $note ? join ("\n",map {'# '.$_} split /\n/,$note ) : undef;
+                push @v, $comment ? [ $value, $comment ] : $value;
+            }
+            push @section, $elt , \@v if @v;
+        }
+        elsif ($type eq 'check_list') {
+            my $v = $node->fetch_element($elt)->fetch ;
+            push @section, $elt , $v if $v ;
+        }
+        elsif ($elt eq 'Synopsis') {
+            my $v = $node->fetch_element_value($elt) ;
+            push @section, 'Description' , $v ; # mandatory field
+            $description_ref = \$section[$#section] ;
+        }
+        elsif ($elt eq 'Description') {
+            # annotation attached to Description is written as a
+            # comment *after* the Description block
+            $$description_ref .= "\n".$node->fetch_element_value($elt) ; # mandatory field
+        }
+        else {
+            my $v = $node->fetch_element_value($elt) ;
+            push @section, $elt , $v if $v ;
+        }
+    }
+    return @section ;
+}
 1;
 
 __END__
