@@ -14,7 +14,7 @@ use Path::Tiny;
 use Data::Dumper;
 
 use Config::Model::DumpAsData;
-use Dpkg::Copyright::Scanner qw/scan_files __squash __pack_files __create_tree_leaf_from_paths/;
+use Dpkg::Copyright::Scanner qw/scan_files __squash __pack_files __pack_copyright __create_tree_leaf_from_paths/;
 use Software::LicenseUtils;
 use Scalar::Util qw/weaken/;
 use Storable qw/dclone/;
@@ -69,6 +69,9 @@ sub update ($self, %args) {
         my $node = $files_obj->fetch_with_id($paths_str) ;
         my $data = $dumper->dump_as_data( node => $node );
 
+        # normalise existing copyright data (mandatory parameter, no need to test)
+        $data->{Copyright} = __pack_copyright($data->{Copyright});
+
         if ($paths_str =~ m!^debian/!) {
             $debian_paths{$paths_str} = $data;
         }
@@ -227,7 +230,7 @@ sub update ($self, %args) {
         # if full_license is not provided in datum, check global license(s)
         if (not $datum->{License}{full_license}) {
             my $ok = 0;
-            my @sub_licenses = split /\s+or\s+/,$l;
+            my @sub_licenses = split /[,\s]+(?:or|and)[,\s]+/,$l;
             my $lic_count = 0;
             my @empty_licenses = grep {
                 my $text = $self->grab_value(steps => qq!License:"$_" text!, check =>'no') ;
@@ -311,7 +314,7 @@ sub _apply_fix_scan_copyright_file ($self, $current_dir) {
         $self->_say( "Note: loading @fixes fixes from copyright fix files") if @fixes;
         foreach my $fix ( @fixes) {
             my @l = grep { /[^\s]/ } grep { ! m!^(#|//)!  } $fix->lines_utf8;
-            eval { $self->load( join(' ',@l) ); };
+            eval { $self->load( steps => join(' ',@l) , caller_is_root => 1 ); };
             my $e = $@;
             if ($e) {
                 my $msg = $e->full_message;
