@@ -141,6 +141,7 @@ push @virtual_list,
   qw/
 		libgl-dev
 		libtiff-dev
+        libuv-dev
 		ruby-interpreter
         ssh-client
         ssh-server
@@ -975,6 +976,11 @@ sub extract_madison_info ($json) {
                 # see #841667: relevant pkg version is found in arch all or arch amd64
                 my @keep = grep { $_ eq 'all' or $_ eq 'amd64'} $arches->@*;
 
+                # except when a package is not delivered at all on amd64. See #875955
+                if (not @keep) {
+                    @keep = grep { $_ ne 'source' } $arches->@*;
+                }
+
                 # the same version may be available in several
                 # distributions (testing and unstable are more likely
                 # to have the same version for a package)
@@ -986,6 +992,12 @@ sub extract_madison_info ($json) {
         # @res contains something like 'oldstable 5.10.1-17 stable 5.14.2-21 testing 5.18.1-3 unstable 5.18.1-4'
         my @res = map { $avail{$_}->@* ; } sort { $vs->compare($a,$b) } keys %avail ;
 
+        if (not @res) {
+            warn "ERROR: Could not extract useful info from madison for package $name. ",
+                "Please report this issue using 'reportbug libconfig-model-dpkg-perl'\n";
+            next;
+        }
+
         $ref{$name} = \@res ;
         $cache{$name} = join(' ',time, @res) ;
 	}
