@@ -221,18 +221,33 @@ By default, it will include all existing files in the top-level source directory
         'description' => 'watch file used by L<uscan> to monitor upstream sources',
         'type' => 'leaf',
         'value_type' => 'string'
+      },
+      'tests',
+      {
+        'config_class_name' => 'Dpkg::Tests',
+        'level' => 'hidden',
+        'type' => 'warped_node',
+        'warp' => {
+          'follow' => {
+            'testsuite' => '- control source Testsuite'
+          },
+          'rules' => [
+            'not $testsuite',
+            {
+              'level' => 'normal'
+            }
+          ]
+        }
       }
     ],
     'license' => 'LGPL2',
     'name' => 'Dpkg',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'auto_delete' => '1',
-        'backend' => 'Dpkg',
-        'config_dir' => 'debian'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'auto_delete' => '1',
+      'backend' => 'Dpkg',
+      'config_dir' => 'debian'
+    }
   }
 ]
 ;
