@@ -21,15 +21,13 @@
       }
     ],
     'name' => 'Dpkg::BugFiles',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'auto_delete' => '1',
-        'backend' => 'PlainFile',
-        'config_dir' => 'debian',
-        'file' => '&index(-).&element'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'auto_delete' => '1',
+      'backend' => 'PlainFile',
+      'config_dir' => 'debian',
+      'file' => '&index(-).&element'
+    }
   }
 ]
 ;
