@@ -7,7 +7,7 @@
 
 Fields in the main source control information file with names starting X, followed by one or more of the letters BCS and a hyphen -, will be copied to the output files. Only the part of the field name after the hyphen will be used in the output file. Where the letter B is used the field will appear in binary package control files, where the letter S is used in Debian source control files and where C is used in upload control (.changes) files.
 
-For details, see L<section 5.7 of Debian policy|https://www.debian.org/doc/debian-policy/ch-controlfields.html>',
+For details, see L<section 5.7 of Debian policy|https://www.debian.org/doc/debian-policy/#document-ch-controlfields>',
         'summary' => 'User defined field',
         'type' => 'leaf',
         'value_type' => 'string'
@@ -62,6 +62,26 @@ If the maintainer\'s name contains a full stop then the whole field will not wor
         },
         'type' => 'list'
       },
+      'Standards-Version',
+      {
+        'default' => '4.1.3',
+        'description' => 'This field indicates the Debian policy version number this package complies to.
+
+Before updating this field, please read L<upgrading-checklist|https://www.debian.org/doc/debian-policy/#document-upgrading-checklist>
+to know what changes came with a new policy version number and apply the required changes (if any) to your package.',
+        'match' => '\\d+\\.\\d+\\.\\d+(\\.\\d+)?',
+        'summary' => 'Debian policy version number this package complies to',
+        'type' => 'leaf',
+        'value_type' => 'uniline',
+        'warn_unless' => {
+          'current' => {
+            'code' => '$_ eq $self->_fetch_std;',
+            'fix' => '$_ = undef; # restore default value',
+            'msg' => 'Current standards version is \'$std_value\'. Please read file:///usr/share/doc/debian-policy/upgrading-checklist.txt.gz to check what changes need to applied to your package to upgrade it from standard version \'$_\' to \'$std_value\'.
+'
+          }
+        }
+      },
       'Section',
       {
         'default' => 'misc',
@@ -70,7 +90,7 @@ grouped further into sections to simplify handling.
 
 The archive area and section for each package should be specified in
 the package\'s Section control record (see 
-L<Section 5.6.5|http://www.debian.org/doc/debian-policy/ch-controlfields.html#s-f-Section>). 
+L<Section 5.6.5|http://www.debian.org/doc/debian-policy/#section>).
 However, the maintainer of the Debian archive may override
 this selection to ensure the consistency of the Debian
 distribution. The Section field should be of the form:
@@ -128,27 +148,27 @@ area/section if the package is in the contrib or non-free archive areas.
         'warn_unless' => {
           'defined-test' => {
             'code' => 'my $m = $self->grab_value(\'- Maintainer\');
-my ($team) = ( $m =~ /(pkg-(?:perl|ruby))/ );
-not defined $team or defined $_;',
+my ($team) = ( $m =~ /(pkg-(?:perl|ruby|go))/ );
+not defined $team or defined $_ or file(\'debian/tests/control\')->exists;',
             'fix' => 'my $m = $self->grab_value(\'- Maintainer\');
-my ($str) = ($m =~ /pkg-(perl|ruby)/);
+my ($str) = ($m =~ /pkg-(perl|ruby|go)/);
 $_ = $str ? \'autopkgtest-pkg-\'.$str : undef;',
             'msg' => 'Undefined while packaging team supports test suite'
           },
           'team-test' => {
             'code' => 'my $m = $self->grab_value(\'- Maintainer\');
-my ($team) = ( $m =~ /(pkg-(?:perl|ruby))/ );
-not defined $_ or not defined $team or $_ eq \'autopkgtest-\'.$team ;',
+my ($team) = ( $m =~ /(pkg-(?:perl|ruby|go))/ );
+not defined $_ or not defined $team or $_ eq \'autopkgtest-\'.$team  or -e \'debian/tests/control\';',
             'fix' => 'my $m = $self->grab_value(\'- Maintainer\');
-my ($str) = ($m =~ /pkg-(perl|ruby)/);
+my ($str) = ($m =~ /pkg-(perl|ruby|go)/);
 $_ = $str ? \'autopkgtest-pkg-\'.$str : undef;',
             'msg' => 'value does not match maintainer team'
           }
         },
         'warn_unless_match' => {
-          '^autopkgtest(-pkg-(perl|ruby))?$' => {
+          '^autopkgtest(-pkg-(dkms|elpa|go|nodejs|octave|perl|python|r|ruby))?$' => {
             'fix' => 'my $m = $self->grab_value(\'- Maintainer\');
-my ($str) = ($m =~ /pkg-(perl|ruby)/);
+my ($str) = ($m =~ /pkg-(perl|ruby|go)/);
 $_ = $str ? \'autopkgtest-pkg-\'.$str : undef;',
             'msg' => 'Unknown value'
           }
@@ -198,7 +218,20 @@ in Debian developer reference.',
           'standard' => 'These packages provide a reasonably small but not too limited character-mode system. This is what will be installed by default if the user doesn\'t select anything else. It doesn\'t include many large applications. '
         },
         'type' => 'leaf',
-        'value_type' => 'enum'
+        'value_type' => 'enum',
+        'warp' => {
+          'follow' => {
+            'std_ver' => '- Standards-Version'
+          },
+          'rules' => [
+            '$std_ver ge \'4.0.1\'',
+            {
+              'replace' => {
+                'extra' => 'optional'
+              }
+            }
+          ]
+        }
       },
       'Build-Depends',
       {
@@ -213,6 +246,7 @@ in Debian developer reference.',
             }
           }
         },
+        'class' => 'Config::Model::Dpkg::DependencyList',
         'description' => 'List of packages that must be installed:
 
 '.'=over
@@ -227,7 +261,8 @@ to build architecture-dependent binaries ("Architecture: any" or specific archit
 
 '.'=back
 
-Technically, these packages must be installed for the following build targets: clean, build-arch, and binary-arch. See L<build target|https://www.debian.org/doc/debian-policy/ch-source.html#s-debianrules> doc and L<details on this field|https://www.debian.org/doc/debian-policy/ch-relationships.html#s-sourcebinarydeps>.
+Technically, these packages must be installed for the following build targets: clean, build-arch, and binary-arch.
+See L<build target|https://www.debian.org/doc/debian-policy/#relationships-between-source-and-binary-packages-build-depends-build-depends-indep-build-depends-arch-build-conflicts-build-conflicts-indep-build-conflicts-arch>.
 
 On the other hand, the list of packages that must be installed to build architecture-independent binaries ("Architecture: all") should be listed in "Build-Depends-Indep" field.
 
@@ -245,6 +280,7 @@ See also L<deb-src-control|https://manpages.debian.org/unstable/dpkg-dev/deb-src
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'class' => 'Config::Model::Dpkg::DependencyList',
         'description' => 'Same as Build-Depends, but these pakcages are only needed when building the architecture dependent packages. The Build-Depends are also installed in this case. 
 
 See L<deb-src-control man page|https://manpages.debian.org/unstable/dpkg-dev/deb-src-control.5.en.html> for details',
@@ -259,9 +295,11 @@ See L<deb-src-control man page|https://manpages.debian.org/unstable/dpkg-dev/deb
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'class' => 'Config::Model::Dpkg::DependencyList',
         'description' => 'List of packages that must be installed to build architecture-independent binaries ("Architecture: all").
 
-Technically, these packages must be installed for the following build targets: build, build-indep, binary, and binary-indep. See L<build target|https://www.debian.org/doc/debian-policy/ch-source.html#s-debianrules> doc and L<details on this field|https://www.debian.org/doc/debian-policy/ch-relationships.html#s-sourcebinarydeps>.
+Technically, these packages must be installed for the following build targets: build, build-indep, binary, and binary-indep.
+See L<build target|https://www.debian.org/doc/debian-policy/#relationships-between-source-and-binary-packages-build-depends-build-depends-indep-build-depends-arch-build-conflicts-build-conflicts-indep-build-conflicts-arch>.
 
 Note that packages required during "clean" phase must be declared in "Build-Depends" field.',
         'duplicates' => 'warn',
@@ -274,6 +312,7 @@ Note that packages required during "clean" phase must be declared in "Build-Depe
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'class' => 'Config::Model::Dpkg::DependencyList',
         'description' => 'List of packages that must be missing (i.e. B<not> installed):
 
 '.'=over
@@ -288,7 +327,8 @@ to build architecture-dependent binaries ("Architecture: any" or specific archit
 
 '.'=back
 
-Technically, these packages must B<not> be installed for the following build targets: clean, build-arch, and binary-arch. See L<build target|https://www.debian.org/doc/debian-policy/ch-source.html#s-debianrules> doc and L<details on this field|https://www.debian.org/doc/debian-policy/ch-relationships.html#s-sourcebinarydeps>.
+Technically, these packages must B<not> be installed for the following build targets: clean, build-arch, and binary-arch.
+See L<build target|https://www.debian.org/doc/debian-policy/#relationships-between-source-and-binary-packages-build-depends-build-depends-indep-build-depends-arch-build-conflicts-build-conflicts-indep-build-conflicts-arch>.
 
 On the other hand, the list of packages that must B<not> be installed to build architecture-independent binaries ("Architecture: all") should be listed in "Build-Conflicts-Indep" field.
 
@@ -305,6 +345,7 @@ See L<deb-src-control man page|https://manpages.debian.org/unstable/dpkg-dev/deb
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'class' => 'Config::Model::Dpkg::DependencyList',
         'description' => 'List of packages that must be missing (i.e. B<not> installed) to build archictecture dependent binaries 
 
 See L<deb-src-control man page|https://manpages.debian.org/unstable/dpkg-dev/deb-src-control.5.en.html> for details.',
@@ -318,9 +359,11 @@ See L<deb-src-control man page|https://manpages.debian.org/unstable/dpkg-dev/deb
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'class' => 'Config::Model::Dpkg::DependencyList',
         'description' => 'List of packages that must be missing (i.e. B<not> installed) to build binaries with arch set to "all.
 
-Technically, these packages must B<not> be installed for the following build targets: build, build-indep, binary, and binary-indep. See L<build target|https://www.debian.org/doc/debian-policy/ch-source.html#s-debianrules> doc and L<details on this field|https://www.debian.org/doc/debian-policy/ch-relationships.html#s-sourcebinarydeps>.
+Technically, these packages must B<not> be installed for the following build targets: build, build-indep, binary, and binary-indep.
+See L<build target|https://www.debian.org/doc/debian-policy/#relationships-between-source-and-binary-packages-build-depends-build-depends-indep-build-depends-arch-build-conflicts-build-conflicts-indep-build-conflicts-arch>.
 
 Note that packages not wanted during "clean" phase must be declared in "Build-Conflicts" field.',
         'duplicates' => 'warn',
@@ -334,6 +377,7 @@ Note that packages not wanted during "clean" phase must be declared in "Build-Co
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'class' => 'Config::Model::Dpkg::DependencyList',
         'description' => ' Some binary packages incorporate parts of other packages when built but do not have to depend on those packages. Examples include linking with static libraries or incorporating source code from another package during the build. In this case, the source packages of those other packages are a required part of the complete source (the binary package is not reproducible without them).
 
 A Built-Using field must list the corresponding source package for any such binary package incorporated during the build, including an B<exactly equal> ("=") version relation on the version that was used to build that binary package[57].
@@ -350,25 +394,6 @@ A package including binaries from grub2 and loadlin would have this field in its
         'summary' => 'Additional source packages used to build the binary',
         'type' => 'list'
       },
-      'Standards-Version',
-      {
-        'default' => '4.1.0',
-        'description' => 'This field indicates the Debian policy version number this package complies to.
-
-Before updating this field, please read L<upgrading-checklist|https://www.debian.org/doc/debian-policy/upgrading-checklist.html> to know what changes came with a new policy version number and apply the required changes (if any) to your package.',
-        'match' => '\\d+\\.\\d+\\.\\d+(\\.\\d+)?',
-        'summary' => 'Debian policy version number this package complies to',
-        'type' => 'leaf',
-        'value_type' => 'uniline',
-        'warn_unless' => {
-          'current' => {
-            'code' => '$_ eq $self->_fetch_std;',
-            'fix' => '$_ = undef; # restore default value',
-            'msg' => 'Current standards version is \'$std_value\'. Please read file:///usr/share/doc/debian-policy/upgrading-checklist.txt.gz to check what changes need to applied to your package to upgrade it from standard version \'$_\' to \'$std_value\'.
-'
-          }
-        }
-      },
       'Vcs-Browser',
       {
         'compute' => {
