@@ -209,14 +209,12 @@ See L<files pattern documentation|https://www.debian.org/doc/packaging-manuals/c
     ],
     'license' => 'LGPL2',
     'name' => 'Dpkg::Copyright',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'backend' => 'Dpkg::Copyright',
-        'config_dir' => 'debian',
-        'file' => 'copyright'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'backend' => 'Dpkg::Copyright',
+      'config_dir' => 'debian',
+      'file' => 'copyright'
+    }
   }
 ]
 ;
