@@ -14,15 +14,13 @@
       }
     ],
     'name' => 'Dpkg::Copyright::FillBlanks',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'auto_delete' => '1',
-        'backend' => 'Yaml',
-        'config_dir' => 'debian',
-        'file' => 'fill.copyright.blanks.yml'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'auto_delete' => '1',
+      'backend' => 'Yaml',
+      'config_dir' => 'debian',
+      'file' => 'fill.copyright.blanks.yml'
+    }
   }
 ]
 ;
