@@ -15,15 +15,13 @@
       }
     ],
     'name' => 'Dpkg::Copyright::ScanPatterns',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'auto_delete' => '1',
-        'backend' => 'Yaml',
-        'config_dir' => 'debian',
-        'file' => 'copyright-scan-patterns.yml'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'auto_delete' => '1',
+      'backend' => 'Yaml',
+      'config_dir' => 'debian',
+      'file' => 'copyright-scan-patterns.yml'
+    }
   }
 ]
 ;
