@@ -26,15 +26,13 @@ See L<dh_install> for more details.
       }
     ],
     'name' => 'Dpkg::Install',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'auto_delete' => '1',
-        'backend' => 'PlainFile',
-        'config_dir' => 'debian',
-        'file' => '&index(-).install'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'auto_delete' => '1',
+      'backend' => 'PlainFile',
+      'config_dir' => 'debian',
+      'file' => '&index(-).install'
+    }
   }
 ]
 ;
