@@ -68,15 +68,13 @@
     ],
     'license' => 'LGPL2',
     'name' => 'Dpkg::Meta',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'backend' => 'Yaml',
-        'config_dir' => '~/',
-        'file' => '.dpkg-meta.yml',
-        'full_dump' => '0'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'backend' => 'Yaml',
+      'config_dir' => '~/',
+      'file' => '.dpkg-meta.yml',
+      'full_dump' => '0'
+    }
   }
 ]
 ;
