@@ -23,14 +23,12 @@
     ],
     'license' => 'LGPL2',
     'name' => 'Dpkg::Patches',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'backend' => 'Dpkg',
-        'config_dir' => 'debian',
-        'file' => 'clean'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'backend' => 'Dpkg',
+      'config_dir' => 'debian',
+      'file' => 'clean'
+    }
   }
 ]
 ;
