@@ -9,7 +9,7 @@ use Exporter::Lite;
 use Array::IntSpan;
 use Path::Tiny;
 use Carp;
-use YAML::Any;
+use YAML::Tiny;
 
 use feature qw/postderef signatures/;
 no warnings qw/experimental::postderef experimental::signatures/;
@@ -196,7 +196,7 @@ sub scan_files ( %args ) {
         }
 
         my $pipe = IO::Pipe->new();
-        my @cmd = (qw/licensecheck --encoding utf8 --copyright --machine --recursive/,
+        my @cmd = (qw/licensecheck --encoding utf8 --copyright --machine --deb-fmt --recursive/,
                    '--ignore='.$regexps{ignore}, '.');
         $pipe->reader(@cmd);
         binmode($pipe, ":encoding(UTF-8)");
@@ -219,6 +219,11 @@ sub scan_files ( %args ) {
         $f =~ s!\./!!;
         next if $files->{$f}; # file already parsed
 
+        # skip copyright because there's no need to have recursive copyrights
+        # skip changelog because it's often contains log entries beginning with copyright
+        # and it's a collective work by nature.
+        next if $f =~  m!debian/(copyright|changelog)!;
+
         # filter out files user does not want checked
         if ( $f !~ $regexps{check} ) {
             # the ignore test should not be usefull as the files are ignored by licensecheck
@@ -226,30 +231,31 @@ sub scan_files ( %args ) {
             next;
         }
 
-        $l =~ s/([*?\\])/\\$1/g;
-        $l =~ s/\s*\(unversioned\/unknown version\)//g;
-        $l =~ s/\s*\(with incorrect FSF address\)//g;
-        $l =~ s/(\w+)\s+\(v([^)]+) or v([^)]+)\)/uc($1)."-$2 or ".uc($1)."-$3"/eg;
-        $l =~ s/\s+\(v([^)]+) or later\)/-$1+/g;
-        $l =~ s/\s+\(v([^)]+)\)/-$1/g;
-        $l =~ s/^\s*(GENERATED FILE)/UNKNOWN/g;
-        $l =~ s/\s+(GENERATED FILE)//g;
-        $l =~ s/\bzlib\/libpng\b/Zlib/g;
-        $l =~ s/\bMIT\/X11 \(BSD like\)/Expat/g;
-        $l =~ s/\bBSD \((\d) clause\)/BSD-$1-clause/g;
-        $l =~ s/\bpublic domain\b/public-domain/ig;
+        # $l =~ s/([*?\\])/\\$1/g;
+        # $l =~ s/\s*\(unversioned\/unknown version\)//g;
+        # $l =~ s/\s*\(with incorrect FSF address\)//g;
+        # $l =~ s/(\w+)\s+\(v([^)]+) or v([^)]+)\)/uc($1)."-$2 or ".uc($1)."-$3"/eg;
+        # $l =~ s/\s+\(v([^)]+) or later\)/-$1+/g;
+        # $l =~ s/\s+\(v([^)]+)\)/-$1/g;
+        # $l =~ s/^\s*(GENERATED FILE)/UNKNOWN/g;
+        # $l =~ s/\s+(GENERATED FILE)//g;
+        # $l =~ s/\bzlib\/libpng\b/Zlib/g;
+        # $l =~ s/\bMIT\/X11 \(BSD like\)/Expat/g;
+        # $l =~ s/\bBSD \((\d) clause\)/BSD-$1-clause/g;
+        # $l =~ s/\bpublic domain\b/public-domain/ig;
 
 
-        # deduplicate license keywords and add 'or' keyword where missing
-        # this is fragile. may need to change license-check to output license keyword
-        my %tmp_l = map { ( $_ => 1) ;} grep { $_ ne 'or' } split(/ /,$l);
-        $l = join(' or ', sort keys %tmp_l) ;
+        # # deduplicate license keywords and add 'or' keyword where missing
+        # # this is fragile. may need to change license-check to output license keyword
+        # my %tmp_l = map { ( $_ => 1) ;} grep { $_ ne 'or' } split(/ /,$l);
+        # $l = join(' or ', sort keys %tmp_l) ;
 
         # Handle license like "under the same term as Perl"
-        $l =~ s/perl/Artistic or GPL-1+/i;
+        # $l =~ s/perl/Artistic or GPL-1+/i;
 
         $c =~ s/'//g;
-        $c =~ s/^&copy;\s*//;
+        $c =~ s/^&copy;\s*//g;
+        $c =~ s/\(c\)\s*//g;
         $c =~ s/(?<=\b\d{4})\s*-\s*\d{4}(?=\s*-\s*(\d{4})\b)//g;
         $c =~ s/(\d+)\s*-\s*(\d+)/$1-$2/g;
         $c =~ s/\b(\d{4}),?\s+([\S^\d])/$1, $2/g;
@@ -366,7 +372,8 @@ sub __pack_copyright ($r) {
     return $r if $r eq 'no-info-found';
     my %cop;
     $r =~ /^[\s\W]+|[\s\W]+$/g;
-    foreach my $c ( split( m!\s+/\s+!, $r)) {
+    # split licensescheck output or debfmt data
+    foreach my $c ( split( m!(?:\s+/\s+)|(?:\s*\n\s*)!, $r) ) {
         my ($owner, @data) = __split_copyright($c);
         return $r unless defined $owner;
         $cop{$owner} ||= [] ;
