@@ -19,6 +19,7 @@ providing the following file:
         # t0
         check => {
             'source Source',          "libdist-zilla-plugins-cjm-perl",
+            'source Standards-Version', "4.1.3",
             'source Build-Depends:0', "debhelper (>= 7)",
             # not really happy about the versioned dep of libmeta-cpan-perl created ex-nihilo.
             # this is a side effect of other compromises in dual dependency handling which should be harmless
@@ -28,6 +29,7 @@ providing the following file:
             'source Build-Depends-Indep:6', "libmodule-build-perl (>= 0.360000) | perl (<< 5.19.0)", # fixed
             'source Build-Depends-Indep:7', "udev [linux-any] | makedev [linux-any]",
             'source X-Comment' => qr/Debian #810023/,
+            'source Priority' => 'optional',
             'binary:libdist-zilla-plugins-cjm-perl X-Comment' => qr/Debian #810023/,
 
             'binary:libdist-zilla-plugins-cjm-perl Depends:0',
@@ -35,18 +37,26 @@ providing the following file:
             'source Vcs-Browser' ,'https://anonscm.debian.org/cgit/pkg-perl/packages/libdist-zilla-plugins-cjm-perl.git',
             'source Vcs-Git', 'https://anonscm.debian.org/git/pkg-perl/packages/libdist-zilla-plugins-cjm-perl.git',
         },
-        load_warnings => [ qr/dependency/, qr/dual life/, (qr/dependency/) x 2, 
-                          qr/libmodule-build-perl \(>= 0.360000\) \| perl \(>= 5.8.8\)/,
-                          qr/should be 'libmodule-build-perl \(>= 0.360000\)/,
-                          qr/standards version/, 
-                           qr/dependency/, qr/dual life/, (qr/dependency/) x 2 ],
+        load_warnings => [
+            qr/standards version/,
+            qr/dependency/, qr/dual life/, (qr/dependency/) x 2,
+            qr/libmodule-build-perl \(>= 0.360000\) \| perl \(>= 5.8.8\)/,
+            qr/should be 'libmodule-build-perl \(>= 0.360000\)/,
+            qr/dependency/, qr/dual life/, (qr/dependency/) x 2
+        ],
         apply_fix => 1,
+        file_contents_like => {
+            'debian/control' => [
+                # check that write order is tweaked for Standards-Version
+                qr!Standards-Version: [\d.]+\nVcs-Browser!
+            ]
+        },
     },
     {
 
         # t1
         check => { 'binary:seaview Recommends:0', 'clustalw', },
-        load_warnings => [ qr/dependency is deprecated/,qr/standards version/, qr/Vcs-Browser/, qr/Vcs-Svn/, qr/too long/ ],
+        load_warnings => [ qr/standards version/, qr/dependency is deprecated/,qr/Vcs-Browser/, qr/Vcs-Svn/, qr/too long/ ],
         apply_fix => 1,
         load => 'binary:seaview Synopsis="multiplatform interface for sequence alignment"',
     },
@@ -87,8 +97,12 @@ providing the following file:
     {
 
         # t4
-        check => { 'source X-Python-Version' => ">= 2.3, << 2.5" },
-        load_warnings => [ (qr/deprecated/) x 1 ],
+        check => {
+            'source Priority' => 'extra',
+            'source X-Python-Version' => ">= 2.3, << 2.5",
+            'source Standards-Version', "3.9.8",
+        },
+        load_warnings => [ qr/Standards-Version/, (qr/deprecated/) x 1 ],
     },
     {
 
@@ -205,6 +219,13 @@ providing the following file:
         file_contents_like => {
             "debian/control" => qr/# Python/,
         }
+    },
+
+    {
+        name => 'tricky-comment',
+        verify_annotation => {
+            'binary:libmoosex-types-iso8601-perl Synopsis' => "not yet packaged\nRecommends",
+        }
     }
 );
 
