@@ -351,6 +351,16 @@ in ‘/usr/share/common-licenses/GPL-1’.",
 #        load_warnings => [ (qr/deprecated/) x 3 ],
 
     },
+    {
+        name => 'new-perl-module',
+        update => { in => path('t/scanner/examples/libtk-fontdialog.in') , quiet => 1 },
+        no_warnings => 1,
+        check => {
+            'Files:"*" Copyright' => qr/Slaven/,
+            # check that Perl license is replaced by Artistic or GPL-1+
+            'Files:"*" License short_name' => 'Artistic or GPL-1+',
+        },
+    }
 );
 
 1;
